SystemOrganization addCategory: #'Glamour-Presentations'!

GLMPresentation subclass: #GLMDynamicPresentation
	instanceVariableNames: 'presentationTransformation'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Presentations'!

!GLMDynamicPresentation commentStamp: 'tg 9/20/2009 14:25' prior: 0!
A GLMDynamicPresentation is a presentation that takes the actual presentation from the display value. Like this, we can have the block of display return a presentation depending on the input.

A usage for this behavior is the Glamorous Editor, which takes the text as input and based on this it displays the browser.!

!GLMDynamicPresentation methodsFor: 'rendering' stamp: 'tg 2/28/2010 23:33'!
currentPresentation 
	| currentPresentation composite |
	composite := GLMCompositePresentation new.
	self presentationTransformation glamourValue: (
			composite asGlamorousMultiValue, 
			self displayValue asGlamorousMultiValue).
	composite pane: self pane.
	^ composite
"	^ self displayValue pane: self pane"! !

!GLMDynamicPresentation methodsFor: 'initialize-release' stamp: 'tg 2/28/2010 23:12'!
initialize 
	super initialize.
	presentationTransformation := [ :aComposite :each | aComposite add: each ]! !

!GLMDynamicPresentation methodsFor: 'accessing' stamp: 'tg 2/28/2010 23:11'!
presentationTransformation
	^ presentationTransformation! !

!GLMDynamicPresentation methodsFor: 'accessing' stamp: 'tg 2/28/2010 23:11'!
presentationTransformation: anObject
	presentationTransformation := anObject! !

!GLMDynamicPresentation methodsFor: 'rendering' stamp: 'tg 1/18/2010 21:30'!
renderGlamorouslyOn: aRenderer 
	self registerAnnouncements.
	^ self currentPresentation renderGlamorouslyOn: aRenderer! !

GLMPresentation subclass: #GLMFlexiblePresentation
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Presentations'!

!GLMFlexiblePresentation commentStamp: '<historical>' prior: 0!
A presentation that flexibly changes it behavior depending on the current entity.

If the entity is a collection, this class renders as a ListPresentation, otherwise as a TextPresentation.!

!GLMFlexiblePresentation methodsFor: 'accessing' stamp: 'tg 5/24/2009 19:21'!
currentPresentation 
	 
	^ (self displayValue isCollection and: [self displayValue isString not])
		ifTrue: [GLMListPresentation new pane: self pane]
		ifFalse: [GLMTextPresentation new pane: self pane]! !

!GLMFlexiblePresentation methodsFor: 'rendering' stamp: 'tg 1/18/2010 21:31'!
renderGlamorouslyOn: aRenderer 
	self registerAnnouncements. 
	^self currentPresentation renderGlamorouslyOn: aRenderer! !

GLMPresentation subclass: #GLMMagrittePresentation
	instanceVariableNames: 'magritteDescription'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Presentations'!

!GLMMagrittePresentation methodsFor: 'accessing' stamp: 'tg 5/15/2009 13:53'!
description: anObject
	"convenience method for scripting"
	
	magritteDescription := anObject! !

!GLMMagrittePresentation methodsFor: 'accessing' stamp: 'tg 5/14/2009 17:22'!
magritteDescription
	"By default the we read it via the #description selector"
	^ magritteDescription ifNil: [ magritteDescription := #description ]! !

!GLMMagrittePresentation methodsFor: 'rendering' stamp: 'tg 5/6/2009 13:17'!
renderGlamorouslyOn: aRenderer 
	^ aRenderer renderMagrittePresentation: self! !

GLMPresentation subclass: #GLMMondrianPresentation
	instanceVariableNames: 'painting view'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Presentations'!

!GLMMondrianPresentation commentStamp: 'tg 9/20/2009 14:28' prior: 0!
A GLMMondrianPresentation delegates the actual presenation to the Mondrian visualization engine. The only parameter it takes is a painting block to which it passes an instance of a ViewRenderer.

Instance Variables
	painting:		aBlock that takes a ViewRenderer as the first parameter!

!GLMMondrianPresentation methodsFor: 'accessing' stamp: ' 4/5/09 22:18'!
painting 
	 
	^painting! !

!GLMMondrianPresentation methodsFor: 'accessing' stamp: ' 4/5/09 22:18'!
painting: anObject 
	 
	painting := anObject! !

!GLMMondrianPresentation methodsFor: 'rendering' stamp: 'tg 1/18/2010 21:27'!
renderGlamorouslyOn: aRenderer
	self registerAnnouncements.
	^aRenderer renderMondrianPresentation: self! !

!GLMMondrianPresentation methodsFor: 'accessing' stamp: 'VeronicaUquillas 5/19/2010 18:43'!
renderOn: aView
	self flag: 'find a smarter solution that does not depend on isKindOf:'. 
	self painting glamourValue: (
		(self entity isKindOf: GLMMultiValue) 
				ifTrue: [(GLMMultiValue with: aView) , self entity , (GLMMultiValue with: self)] 
				ifFalse: [GLMMultiValue with: aView with: self entity with: self])! !

!GLMMondrianPresentation methodsFor: 'accessing' stamp: 'tg 4/1/2010 10:38'!
view
	^ view ifNil: [view := MOViewRenderer new]! !

!GLMMondrianPresentation methodsFor: 'accessing' stamp: 'tg 4/1/2010 10:38'!
view: anObject
	view := anObject! !

GLMPresentation subclass: #GLMMorphPresentation
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Presentations'!

!GLMMorphPresentation methodsFor: 'rendering' stamp: 'lr 11/7/2009 11:39'!
renderGlamorouslyOn: aRenderer 
	^ aRenderer renderMorphPresentation: self! !

Object subclass: #GLMTableColumn
	instanceVariableNames: 'title computation'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Presentations'!

!GLMTableColumn methodsFor: 'accessing' stamp: 'tg 11/16/2009 03:29'!
computation
	^ computation! !

!GLMTableColumn methodsFor: 'accessing' stamp: 'tg 11/16/2009 03:29'!
computation: anObject
	computation := anObject! !

!GLMTableColumn methodsFor: 'accessing' stamp: 'tg 11/16/2009 03:29'!
title
	^ title! !

!GLMTableColumn methodsFor: 'accessing' stamp: 'tg 11/16/2009 03:29'!
title: anObject
	title := anObject! !

GLMFormatedPresentation subclass: #GLMActionListPresentation
	instanceVariableNames: 'isHorizontal'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Presentations'!

!GLMActionListPresentation methodsFor: 'accessing' stamp: 'tg 11/8/2009 20:54'!
isHorizontal
	^ isHorizontal ifNil: [isHorizontal := false]! !

!GLMActionListPresentation methodsFor: 'accessing' stamp: 'tg 11/8/2009 20:53'!
isHorizontal: anObject
	isHorizontal := anObject! !

!GLMActionListPresentation methodsFor: 'accessing' stamp: 'tg 11/8/2009 20:53'!
isVertical
	^ self isHorizontal not! !

!GLMActionListPresentation methodsFor: 'rendering' stamp: 'tg 11/8/2009 20:50'!
renderGlamorouslyOn: aRenderer
	self registerAnnouncements.
	^ aRenderer renderActionListPresentation: self! !

GLMFormatedPresentation subclass: #GLMDiffPresentation
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Presentations'!

!GLMDiffPresentation methodsFor: 'rendering' stamp: 'tg 1/18/2010 21:30'!
renderGlamorouslyOn: aRenderer 
	self registerAnnouncements.
	^ aRenderer renderDiffPresentation: self! !

GLMFormatedPresentation subclass: #GLMDropDownListPresentation
	instanceVariableNames: 'selectedIndex'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Presentations'!

!GLMDropDownListPresentation methodsFor: 'rendering' stamp: 'VeronicaUquillas 5/26/2010 15:06'!
defaultValidate: anObject on: aPort
	"we only allow objects that are in the display value"

	(aPort name == #selection) ifFalse: [ ^ true ].
	self entity isNil ifTrue: [ ^ false ].
	^ self displayValue includes: anObject ! !

!GLMDropDownListPresentation methodsFor: 'rendering' stamp: 'VeronicaUquillas 5/26/2010 13:43'!
renderGlamorouslyOn: aRenderer 
	self registerAnnouncements.
	^ aRenderer renderDropDownListPresentation: self! !

!GLMDropDownListPresentation methodsFor: 'accessing' stamp: 'VeronicaUquillas 5/18/2010 20:17'!
selectedIndex
	^ selectedIndex ifNil:[ selectedIndex := 0 ] ! !

!GLMDropDownListPresentation methodsFor: 'accessing' stamp: 'VeronicaUquillas 5/18/2010 18:05'!
selectedIndex: index
	
	selectedIndex:= index! !

GLMFormatedPresentation subclass: #GLMListingPresentation
	instanceVariableNames: 'tagsBlock searchBlock filterBlock amountToShowBlock allowsMultipleSelection tagsFilterBlock allowsDeselection'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Presentations'!

GLMListingPresentation subclass: #GLMListPresentation
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Presentations'!

!GLMListPresentation methodsFor: 'validation' stamp: 'VeronicaUquillas 5/18/2010 18:01'!
defaultValidate: anObject on: aPort
	"we only allow objects that are in the display value"

	(aPort name == #selection) ifFalse: [ ^ true ].
	self entity isNil ifTrue: [ ^ false ].
	^ self isMultiple
		ifTrue: [ anObject isCollection and: [
				anObject allSatisfy: [:each | self displayValue includes: each ] ]]
		ifFalse: [ self displayValue includes: anObject ]! !

!GLMListPresentation methodsFor: 'rendering' stamp: 'tg 11/8/2009 01:06'!
renderGlamorouslyOn: aRenderer 
	self registerAnnouncements.
	^ aRenderer renderListPresentation: self! !

!GLMListingPresentation methodsFor: 'accessing' stamp: 'tg 12/29/2009 00:24'!
allowsDeselection
	^ allowsDeselection ifNil: [allowsDeselection := false]! !

!GLMListingPresentation methodsFor: 'accessing' stamp: 'tg 12/29/2009 00:24'!
allowsDeselection: anObject
	allowsDeselection := anObject! !

!GLMListingPresentation methodsFor: 'testing' stamp: 'tg 9/27/2009 23:42'!
allowsFilter
	^ filterBlock notNil! !

!GLMListingPresentation methodsFor: 'testing' stamp: 'tg 9/27/2009 23:42'!
allowsInput
	^ self allowsFilter or: [ self allowsSearch ]! !

!GLMListingPresentation methodsFor: 'testing' stamp: 'tg 9/27/2009 23:42'!
allowsSearch
	^ searchBlock notNil! !

!GLMListingPresentation methodsFor: 'accessing' stamp: 'tg 9/30/2009 01:28'!
amountToShow
	^ amountToShowBlock glamourValue: self entity! !

!GLMListingPresentation methodsFor: 'accessing' stamp: 'tg 11/13/2009 01:22'!
childrenValueOf: anObject
	self flag: 'this is rather hackish, but needed to treat list and tree in the same way.'.
	^ OrderedCollection new! !

!GLMListingPresentation methodsFor: 'accessing' stamp: 'tg 4/18/2010 23:21'!
childrenValueOf: anObject atLevel: anInteger
	self flag: 'this is rather hackish, but needed to treat list and tree in the same way.'.
	^ OrderedCollection new! !

!GLMListingPresentation methodsFor: 'accessing' stamp: 'tg 11/16/2009 04:10'!
columns
	self flag: 'this is rather hackish, but needed to treat list and tree in the same way.'.
	^ OrderedCollection new! !

!GLMListingPresentation methodsFor: 'accessing' stamp: 'tg 9/22/2009 08:36'!
filterStrategy
	^filterBlock! !

!GLMListingPresentation methodsFor: 'testing' stamp: 'tg 9/13/2009 04:16'!
hasTags
	^ tagsBlock notNil! !

!GLMListingPresentation methodsFor: 'testing' stamp: 'VeronicaUquillas 11/19/2009 19:24'!
hasTagsFilter
	^ tagsFilterBlock notNil! !

!GLMListingPresentation methodsFor: 'testing' stamp: 'tg 10/5/2009 00:37'!
isMultiple
	^ allowsMultipleSelection ifNil: [ allowsMultipleSelection := false ]! !

!GLMListingPresentation methodsFor: 'testing' stamp: 'tg 10/5/2009 00:37'!
isSingle 
	^ self isMultiple not! !

!GLMListingPresentation methodsFor: 'testing' stamp: 'tg 9/30/2009 01:49'!
limitsAmount
	^ amountToShowBlock notNil! !

!GLMListingPresentation methodsFor: 'accessing' stamp: 'tg 9/22/2009 08:36'!
searchStrategy
	^ searchBlock! !

!GLMListingPresentation methodsFor: 'accessing' stamp: 'tg 11/13/2009 01:27'!
selectionPath
	^ (self pane port: #selectionPath) value! !

!GLMListingPresentation methodsFor: 'accessing' stamp: 'tg 11/13/2009 01:27'!
selectionPath: anObject
	(self pane port: #selectionPath) value: anObject! !

!GLMListingPresentation methodsFor: 'accessing' stamp: 'tg 9/13/2009 04:12'!
tagsBlock
	^ tagsBlock! !

!GLMListingPresentation methodsFor: 'accessing' stamp: 'tg 9/13/2009 04:12'!
tagsBlock: anObject
	tagsBlock := anObject! !

!GLMListingPresentation methodsFor: 'accessing' stamp: 'VeronicaUquillas 11/2/2009 09:41'!
tagsFilterBlock
	^ tagsFilterBlock! !

!GLMListingPresentation methodsFor: 'accessing' stamp: 'tg 9/14/2009 23:21'!
tagsFor: anObject
	| value |
	self hasTags ifFalse: [ ^ OrderedCollection new ].
	value := self tagsBlock glamourValue: (anObject asGlamorousMultiValue, self entity asGlamorousMultiValue).
	^ value isString
		ifTrue: [ OrderedCollection with: value ]
		ifFalse: [ value asOrderedCollection ]! !

!GLMListingPresentation methodsFor: 'accessing' stamp: 'VeronicaUquillas 11/19/2009 19:25'!
tagsFor: anObject to: operation
	| value hasTags tags |
	
	operation == #show 
	ifTrue: [ hasTags := self hasTags.
				tags := self tagsBlock ] 
	ifFalse: [ hasTags := self hasTagsFilter.
				 tags := self tagsFilterBlock ].
	
	hasTags ifFalse: [ ^ OrderedCollection new ].
	value := tags glamourValue: (anObject asGlamorousMultiValue, self entity asGlamorousMultiValue).
	^ value isString
		ifTrue: [ OrderedCollection with: value ]
		ifFalse: [ value asOrderedCollection ]! !

GLMListingPresentation subclass: #GLMTablePresentation
	instanceVariableNames: 'columns'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Presentations'!

!GLMTablePresentation methodsFor: 'accessing' stamp: 'tg 11/16/2009 03:31'!
addColumn: aColumn
	self columns add: aColumn! !

!GLMTablePresentation methodsFor: 'private' stamp: 'tg 4/20/2010 16:04'!
column: aGlamourColumn valueFor: anObject
	^ aGlamourColumn computation glamourValue: 
		(anObject asGlamorousMultiValue,
		 self entity asGlamorousMultiValue)! !

!GLMTablePresentation methodsFor: 'accessing' stamp: 'tg 11/16/2009 03:32'!
columns
	^ columns ifNil: [ columns := OrderedCollection new ]! !

!GLMTablePresentation methodsFor: 'accessing' stamp: 'tg 11/16/2009 03:32'!
columns: aCollection
	columns := aCollection ! !

!GLMTablePresentation methodsFor: 'rendering' stamp: 'tg 11/16/2009 03:32'!
renderGlamorouslyOn: aRenderer 
	self registerAnnouncements.
	^ aRenderer renderTablePresentation: self! !

!GLMTablePresentation methodsFor: 'private' stamp: 'tg 4/20/2010 16:37'!
titleValueOfColumn: aColumn
	^ aColumn title glamourValue: self entity! !

GLMListingPresentation subclass: #GLMTreePresentation
	instanceVariableNames: 'children rootsExpanded allExpanded'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Presentations'!

!GLMTreePresentation methodsFor: 'validation' stamp: 'tg 11/15/2009 16:47'!
allDisplayedDo: aBlock
	self displayValue do: [ :eachRoot | 
		self withChildrenOf: eachRoot do: aBlock ]! !

!GLMTreePresentation methodsFor: 'accessing' stamp: 'tg 1/15/2010 11:26'!
allExpanded
	self shouldAllExpand: true! !

!GLMTreePresentation methodsFor: 'accessing' stamp: ' 4/5/09 22:18'!
children 
	 
	^children! !

!GLMTreePresentation methodsFor: 'accessing' stamp: ' 4/5/09 22:18'!
children: anObject 
	 
	children := anObject! !

!GLMTreePresentation methodsFor: 'accessing' stamp: 'tg 11/6/2009 15:46'!
childrenValueOf: anObject
	^ self children glamourValue: (anObject asGlamorousMultiValue, self entity asGlamorousMultiValue)! !

!GLMTreePresentation methodsFor: 'accessing' stamp: 'tg 4/18/2010 23:19'!
childrenValueOf: anObject atLevel: anInteger
	^ self children glamourValue: (
		anObject asGlamorousMultiValue, 
		self entity asGlamorousMultiValue,
		anInteger asGlamorousMultiValue)! !

!GLMTreePresentation methodsFor: 'validation' stamp: 'tg 11/15/2009 16:42'!
defaultValidate: anObject on: aPort
	"we only allow objects that are in the display value"
	(aPort name == #selection) ifFalse: [ ^ true ].
	self entity isNil ifTrue: [ ^ false ].
	self allDisplayedDo: [:each | each = anObject ifTrue: [ ^ true ] ].
	^ false! !

!GLMTreePresentation methodsFor: 'rendering' stamp: 'lr 2/22/2010 13:19'!
renderGlamorouslyOn: aRenderer	
	self registerAnnouncements.
	^ aRenderer renderTreePresentation: self! !

!GLMTreePresentation methodsFor: 'accessing' stamp: 'tg 1/15/2010 11:26'!
rootsExpanded
	self shouldRootsExpand: true! !

!GLMTreePresentation methodsFor: 'accessing' stamp: 'tg 1/15/2010 11:24'!
shouldAllExpand
	^ allExpanded ifNil: [false]! !

!GLMTreePresentation methodsFor: 'accessing' stamp: 'tg 1/15/2010 11:25'!
shouldAllExpand: anObject
	allExpanded := anObject! !

!GLMTreePresentation methodsFor: 'accessing' stamp: 'tg 1/15/2010 11:25'!
shouldRootsExpand
	^ rootsExpanded ifNil: [false]! !

!GLMTreePresentation methodsFor: 'accessing' stamp: 'tg 1/15/2010 11:26'!
shouldRootsExpand: anObject
	rootsExpanded := anObject! !

!GLMTreePresentation methodsFor: 'validation' stamp: 'TestRunner 11/15/2009 16:51'!
withChildrenOf: anObject do: aBlock
	aBlock value: anObject.
	(self childrenValueOf: anObject) do: [ :each |
		self withChildrenOf: each do: aBlock ]! !

GLMFormatedPresentation subclass: #GLMTextualPresentation
	instanceVariableNames: 'selectedText cursorPosition text'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Presentations'!

GLMTextualPresentation subclass: #GLMInputPresentation
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Presentations'!

!GLMInputPresentation methodsFor: 'rendering' stamp: 'tg 3/13/2010 15:28'!
renderGlamorouslyOn: aRenderer 
	self registerAnnouncements.
	^ aRenderer renderInputPresentation: self! !

GLMTextualPresentation subclass: #GLMTextPresentation
	instanceVariableNames: 'selectedTextBlock highlightSmalltalk highlightSmalltalkContext textBlock'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Presentations'!

!GLMTextPresentation methodsFor: 'accessing' stamp: 'tg 8/26/2009 21:04'!
forSmalltalk
	highlightSmalltalk := true! !

!GLMTextPresentation methodsFor: 'accessing' stamp: 'tg 3/1/2010 16:16'!
forSmalltalk: aBlock
	"aBlock takes as parameters the entity objects and 
	its evaluation is expected to produce a Smalltalk class"
	highlightSmalltalk := true.
	highlightSmalltalkContext := aBlock.! !

!GLMTextPresentation methodsFor: 'accessing' stamp: 'tg 8/31/2009 11:44'!
highlightSmalltalk
	^ highlightSmalltalk ifNil: [highlightSmalltalk := false]! !

!GLMTextPresentation methodsFor: 'accessing' stamp: 'tg 8/31/2009 11:42'!
highlightSmalltalkContext
	^ highlightSmalltalkContext isNil 
		ifTrue: [nil] 
		ifFalse: [highlightSmalltalkContext glamourValue: self entity]! !

!GLMTextPresentation methodsFor: 'rendering' stamp: 'tg 1/18/2010 21:30'!
renderGlamorouslyOn: aRenderer 
	self registerAnnouncements.
	^ aRenderer renderTextPresentation: self! !

!GLMTextPresentation methodsFor: 'accessing' stamp: 'tg 8/7/2009 01:24'!
selectedTextBlock
	^ selectedTextBlock ifNil: [ [''] ]! !

!GLMTextPresentation methodsFor: 'accessing' stamp: 'tg 8/7/2009 01:13'!
selectedTextBlock: anObject
	selectedTextBlock := anObject! !

!GLMTextPresentation methodsFor: 'accessing' stamp: 'tg 4/15/2010 18:04'!
selectionInterval
	^ (self pane port: #selectionInterval) value! !

!GLMTextPresentation methodsFor: 'accessing' stamp: 'tg 1/26/2010 11:45'!
selectionInterval: anInterval
	(self pane port: #selectionInterval) value: anInterval! !

!GLMTextPresentation methodsFor: 'accessing' stamp: 'tg 9/14/2009 15:49'!
textBlock
	^ textBlock! !

!GLMTextPresentation methodsFor: 'accessing' stamp: 'tg 9/14/2009 15:48'!
textBlock: anObject 
	textBlock := anObject! !

!GLMTextualPresentation methodsFor: 'accessing' stamp: 'tg 3/13/2010 15:27'!
cursorPosition 
	 
	^cursorPosition! !

!GLMTextualPresentation methodsFor: 'accessing' stamp: 'tg 3/13/2010 15:27'!
cursorPosition: anObject 
	 
	cursorPosition := anObject! !

!GLMTextualPresentation methodsFor: 'accessing' stamp: 'tg 3/13/2010 15:27'!
selectedText
	^ (self pane port: #selectedText) value isNil 
		ifTrue: [self selectedTextBlock value]
		ifFalse: [(self pane port: #selectedText) value]! !

!GLMTextualPresentation methodsFor: 'accessing' stamp: 'tg 3/13/2010 15:27'!
selectedText: anObject	 
	(self pane port: #selectedText) value: anObject copy! !

!GLMTextualPresentation methodsFor: 'accessing' stamp: 'tg 3/13/2010 15:27'!
text
	^ (self pane port: #text) value isNil 
		ifTrue: [self textBlock value]
		ifFalse: [(self pane port: #text) value]! !

!GLMTextualPresentation methodsFor: 'accessing' stamp: 'tg 3/13/2010 15:27'!
text: aString
	(self pane port: #text) value: aString copy! !
